#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_SATURATE_AT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_SATURATE_AT_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/simd/saturate_at.hpp>

#endif
